GatewayRunner

Struct GatewayRunner 

pub struct GatewayRunner { /* private fields */ }
Runs agents via a walrusd Unix domain socket connection.

Implementations

Source

impl GatewayRunner

pub async fn connect(socket_path: &Path) -> Result<Self>

Connect to walrusd.

pub async fn list_agents(&mut self) -> Result<Vec<AgentSummary>>

List all registered agents.

pub async fn agent_info(&mut self, agent: &str) -> Result<ServerMessage>

Get detailed info for a specific agent.

pub async fn list_memory(&mut self) -> Result<Vec<(String, String)>>

List all memory entries.

pub fn download_stream( &mut self, msg: ClientMessage, ) -> impl Stream<Item = Result<ServerMessage>> + '_

Send a download request and return a stream of progress messages.

pub async fn get_memory(&mut self, key: &str) -> Result<Option<String>>

Get a specific memory entry by key.