pub struct GatewayRunner { /* private fields */ }Expand description
Runs agents via a walrusd Unix domain socket connection.
Implementations
Sourceimpl GatewayRunner
impl GatewayRunner
Sourcepub async fn list_agents(&mut self) -> Result<Vec<AgentSummary>>
pub async fn list_agents(&mut self) -> Result<Vec<AgentSummary>>
List all registered agents.
Sourcepub async fn agent_info(&mut self, agent: &str) -> Result<ServerMessage>
pub async fn agent_info(&mut self, agent: &str) -> Result<ServerMessage>
Get detailed info for a specific agent.
Sourcepub fn download_stream(
&mut self,
msg: ClientMessage,
) -> impl Stream<Item = Result<ServerMessage>> + '_
pub fn download_stream( &mut self, msg: ClientMessage, ) -> impl Stream<Item = Result<ServerMessage>> + '_
Send a download request and return a stream of progress messages.